@@ -1,7 +1,7 @@
 /* ACME
- * Copyright (C) 2001 Bastien Nocera <hadess@hadess.net>
+ * Copyright (C) 2001, 2002 Bastien Nocera <hadess@hadess.net>
  *
- * acme.c
+ * acme-properties.c
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -215,6 +215,7 @@ static GtkWidget
 {
 	GladeXML *xml;
 	GtkWidget *window, *treeview, *checkbox, *exec_box, *exec;
+	GdkPixbuf *pixbuf;
 
 	xml = glade_xml_new (ACME_DATA "acme-properties.glade", NULL, NULL);
 
@@ -226,6 +227,10 @@ static GtkWidget
 	g_signal_connect (G_OBJECT (window), "response",
 			G_CALLBACK (response_cb), NULL);
 
+	pixbuf = gdk_pixbuf_new_from_file (ACME_DATA "keymap-48.png", NULL);
+	if (pixbuf != NULL)
+		gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
+
 	checkbox = glade_xml_get_widget (xml, "checkbutton1");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox),
 			gconf_client_get_bool (conf_client,
